@@ -1,5 +1,5 @@
 /*
- * goc-canvas.c :
+ * goc-canvas.c:
  *
  * Copyright (C) 2008-2009 Jean Brefort (jean.brefort@normalesup.org)
  *
@@ -97,7 +97,7 @@ button_press_cb (GocCanvas *canvas, GdkEventButton *event, G_GNUC_UNUSED gpointe
 		canvas->scroll_x1 +  (canvas->width - event->x) / canvas->pixels_per_unit:
 		canvas->scroll_x1 +  event->x / canvas->pixels_per_unit;
 	y = canvas->scroll_y1 + event->y / canvas->pixels_per_unit;
-	item = goc_canvas_get_item_at (canvas, x, y);;
+	item = goc_canvas_get_item_at (canvas, x, y);
 	if (item) {
 		gboolean result;
 		canvas->cur_event = (GdkEvent *) event;
@@ -197,7 +197,7 @@ enter_notify_cb (GocCanvas *canvas, GdkEventCrossing* event, G_GNUC_UNUSED gpoin
 		canvas->scroll_x1 +  (canvas->width - event->x) / canvas->pixels_per_unit:
 		canvas->scroll_x1 +  event->x / canvas->pixels_per_unit;
 	y = canvas->scroll_y1 + event->y / canvas->pixels_per_unit;
-	item = goc_canvas_get_item_at (canvas, x, y);;
+	item = goc_canvas_get_item_at (canvas, x, y);
 	if (item) {
 		canvas->cur_event = (GdkEvent *) event;
 		canvas->last_item = item;
@@ -322,12 +322,18 @@ goc_canvas_init (GocCanvas *canvas)
 #endif
 }
 
+#ifdef GOFFICE_WITH_GTK
+#define CANVAS_BASE_TYPE GTK_TYPE_LAYOUT
+#else
+#define CANVAS_BASE_TYPE G_TYPE_OBJECT
+#endif
+
+
 GSF_CLASS (GocCanvas, goc_canvas,
 	   goc_canvas_class_init, goc_canvas_init,
-#ifdef GOFFICE_WITH_GTK
-	   GTK_TYPE_LAYOUT)
-#else
-	   G_TYPE_OBJECT)
+	   CANVAS_BASE_TYPE)
+#if 0
+;
 #endif
 
 /**
@@ -451,7 +457,7 @@ goc_canvas_get_pixels_per_unit (GocCanvas *canvas)
 }
 
 /**
- * goc_canvas_invalidate :
+ * goc_canvas_invalidate:
  * @canvas: #GocCanvas
  * @x0: minimum x coordinate of the invalidated region in canvas coordinates
  * @y0: minimum y coordinate of the invalidated region in canvas coordinates
@@ -464,9 +470,9 @@ goc_canvas_get_pixels_per_unit (GocCanvas *canvas)
 void
 goc_canvas_invalidate (GocCanvas *canvas, double x0, double y0, double x1, double y1)
 {
-#ifdef GOFFICE_WITH_GTK
-	if (!gtk_widget_get_realized (GTK_WIDGET (canvas)))
+	if (!goc_canvas_get_realized (canvas))
 		return;
+#ifdef GOFFICE_WITH_GTK
 	x0 = (x0 - canvas->scroll_x1) * canvas->pixels_per_unit;
 	y0 = (y0 - canvas->scroll_y1) * canvas->pixels_per_unit;
 	x1 = (x1 - canvas->scroll_x1) * canvas->pixels_per_unit;
@@ -492,6 +498,23 @@ goc_canvas_invalidate (GocCanvas *canvas, double x0, double y0, double x1, doubl
 #endif
 }
 
+/**
+ * goc_canvas_get_realized:
+ * @canvas: #GocCanvas
+ *
+ * Returns: %TRUE if the canvas has been realized as a #GtkWidget.
+ **/
+gboolean
+goc_canvas_get_realized (GocCanvas *canvas)
+{
+#ifdef GOFFICE_WITH_GTK
+	return gtk_widget_get_realized (GTK_WIDGET (canvas));
+#else
+	return FALSE;
+#endif
+}
+
+
 /**
  * goc_canvas_get_item_at:
  * @canvas: #GocCanvas
