@@ -34,6 +34,13 @@
 
 #include <gsf/gsf-impl-utils.h>
 
+enum {
+	PROP_0,
+	PROP_TITLE,
+	PROP_SHOW_ARROW
+};
+
+
 /**
  * GOComboBoxClass:
  * @set_title: sets the title.
@@ -63,7 +70,10 @@ struct _GOComboBoxPrivate {
 	GtkWidget *tearable;	/* The tearoff "button" */
 	GtkWidget *popup;	/* Popup */
 
-	gboolean   updating_buttons;
+	gboolean updating_buttons;
+
+	char *title;
+	gboolean show_arrow;
 };
 static GObjectClass *go_combo_box_parent_class;
 static guint go_combo_box_signals [LAST_SIGNAL] = { 0, };
@@ -115,10 +125,9 @@ go_combo_box_finalize (GObject *object)
 }
 
 static void
-go_combo_box_destroy (GtkWidget *widget)
+go_combo_box_dispose (GObject *obj)
 {
-	GtkWidgetClass *klass = (GtkWidgetClass *)go_combo_box_parent_class;
-	GOComboBox *combo_box = GO_COMBO_BOX (widget);
+	GOComboBox *combo_box = GO_COMBO_BOX (obj);
 
 	if (combo_box->priv->toplevel) {
 		gtk_widget_destroy (combo_box->priv->toplevel);
@@ -132,10 +141,55 @@ go_combo_box_destroy (GtkWidget *widget)
 		combo_box->priv->tearoff_window = NULL;
 	}
 
-	if (klass->destroy)
-                klass->destroy (widget);
+	g_free (combo_box->priv->title);
+	combo_box->priv->title = NULL;
+
+	go_combo_box_parent_class->dispose (obj);
 }
 
+static void
+go_combo_box_get_property (GObject      *object,
+			   guint         prop_id,
+			   GValue       *value,
+			   GParamSpec   *pspec)
+{
+	GOComboBox *combo = GO_COMBO_BOX (object);
+
+	switch (prop_id) {
+	case PROP_TITLE:
+		g_value_set_string (value, combo->priv->title);
+		break;
+	case PROP_SHOW_ARROW:
+		g_value_set_boolean (value, combo->priv->show_arrow);
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+	}
+}
+
+static void
+go_combo_box_set_property (GObject      *object,
+			   guint         prop_id,
+			   GValue const *value,
+			   GParamSpec   *pspec)
+{
+	GOComboBox *combo = GO_COMBO_BOX (object);
+
+	switch (prop_id) {
+	case PROP_TITLE:
+		go_combo_box_set_title (combo, g_value_get_string (value));
+		break;
+	case PROP_SHOW_ARROW:
+		combo->priv->show_arrow = g_value_get_boolean (value);
+		gtk_widget_set_visible (combo->priv->arrow_button,
+					combo->priv->show_arrow);
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+	}
+}
+
+
 /* Cut and paste from gtkwindow.c */
 static void
 do_focus_change (GtkWidget *widget, gboolean in)
@@ -152,6 +206,7 @@ static void
 set_arrow_state (GOComboBox *combo_box, gboolean state)
 {
 	GOComboBoxPrivate *priv = combo_box->priv;
+
 	g_return_if_fail (!combo_box->priv->updating_buttons);
 
 	combo_box->priv->updating_buttons = TRUE;
@@ -250,9 +305,26 @@ go_combo_box_class_init (GObjectClass *object_class)
 	go_combo_box_parent_class = g_type_class_peek_parent (object_class);
 
 	object_class->finalize = go_combo_box_finalize;
+	object_class->dispose = go_combo_box_dispose;
+	object_class->get_property = go_combo_box_get_property;
+	object_class->set_property = go_combo_box_set_property;
+
+	g_object_class_install_property (object_class,
+		PROP_TITLE,
+		g_param_spec_string ("title", _("Title"),
+			_("The combo box' title"),
+			NULL,
+			G_PARAM_READWRITE | GSF_PARAM_STATIC));
+
+	g_object_class_install_property (object_class,
+		PROP_SHOW_ARROW,
+		g_param_spec_boolean ("show-arrow", _("Show Arrow"),
+			_("Whether to show an arrow for the combo"),
+			TRUE,
+			G_PARAM_READWRITE | GSF_PARAM_STATIC));
+
 	widget_class->mnemonic_activate = go_combo_box_mnemonic_activate;
 	widget_class->realize = go_combo_box_realize;
-	((GtkWidgetClass *)object_class)->destroy = go_combo_box_destroy;
 
 	gtk_widget_class_install_style_property
 		(widget_class,
@@ -523,6 +595,7 @@ go_combo_box_init (GOComboBox *combo_box)
 
 	combo_box->priv = g_new0 (GOComboBoxPrivate, 1);
 	combo_box->priv->updating_buttons = FALSE;
+	combo_box->priv->show_arrow = TRUE;
 
 	combo_box->priv->arrow_button = gtk_toggle_button_new ();
 	gtk_button_set_relief (GTK_BUTTON (combo_box->priv->arrow_button), GTK_RELIEF_NONE);
@@ -751,10 +824,7 @@ go_combo_box_construct (GOComboBox *combo,
  *
  * This should really change the title even when the popup is already torn off.
  * I guess the tearoff window could attach a listener to title change or
- * something. But I don't think we need the functionality, so I didn't bother
- * to investigate.
- *
- * MW: Just make it a property.
+ * something.
  */
 void
 go_combo_box_set_title (GOComboBox *combo, char const *title)
@@ -764,17 +834,20 @@ go_combo_box_set_title (GOComboBox *combo, char const *title)
 
 	g_return_if_fail (klass != NULL);
 
-	g_object_set_data_full (G_OBJECT (combo), "go-combo-title",
-		g_strdup (title), (GDestroyNotify) g_free);
+	if (g_strcmp0 (title, combo->priv->title) == 0)
+		return;
+
+	g_free (combo->priv->title);
+	combo->priv->title = g_strdup (title);
 
 	if (klass->set_title)
-		(klass->set_title) (combo, title);
+		(klass->set_title) (combo, combo->priv->title);
 }
 
 char const *
 go_combo_box_get_title (GOComboBox *combo)
 {
-	return g_object_get_data (G_OBJECT (combo), "go-combo-title");
+	return combo->priv->title;
 }
 
 /**
@@ -789,7 +862,7 @@ go_combo_box_set_tearable (GOComboBox *combo, gboolean tearable)
 {
 	g_return_if_fail (GO_IS_COMBO_BOX (combo));
 
-	if (tearable){
+	if (tearable) {
 		gtk_widget_show (combo->priv->tearable);
 	} else {
 		go_combo_set_tearoff_state (combo, FALSE);
