@@ -36,6 +36,8 @@
 
 #include <gdk/gdkkeysyms.h>
 #include <glib/gi18n-lib.h>
+#include <gsf/gsf-impl-utils.h>
+#include <stdarg.h>
 
 
 enum {
@@ -58,6 +60,42 @@ go_option_menu_new (void)
 	return g_object_new (GO_TYPE_OPTION_MENU, NULL);
 }
 
+
+/**
+ * go_option_menu_build:
+ * @first_entry: text for first entry
+ * @...: further values and text
+ *
+ * Returns: (transfer full): a new #GOOptionMenu with a filled-in menu.
+ *
+ * This function takes a %NULL-terminated list of string-integer pairs
+ * and fills in a menu with the given texts.  Each menu entry will
+ * have a data property "value" sets to the given value.  The menu is
+ * then placed inside a new #GOOptionMenu which is then returned.
+ */ 
+GtkWidget *
+go_option_menu_build (const char *first_entry, ...)
+{
+	GtkWidget *m = gtk_menu_new ();
+	GtkWidget *om;
+	va_list var_args;
+
+	va_start (var_args, first_entry);
+	while (first_entry) {
+		int v = va_arg (var_args, int);
+		GtkWidget *w = gtk_menu_item_new_with_label (first_entry);
+		gtk_menu_shell_append (GTK_MENU_SHELL (m), w);
+		g_object_set_data (G_OBJECT (w), "value", GINT_TO_POINTER (v));
+		first_entry = va_arg (var_args, char *);
+	}		
+	va_end (var_args);
+	gtk_widget_show_all (m);
+
+	om = go_option_menu_new ();
+	go_option_menu_set_menu (GO_OPTION_MENU (om), m);
+	return om;
+}
+
 static void
 go_option_menu_detacher (GtkWidget *widget, GtkMenu *menu)
 {
@@ -72,25 +110,19 @@ go_option_menu_update_contents (GOOptionMenu *option_menu)
 {
 	const char *text;
 	GtkWidget *w;
+
 	g_return_if_fail (GO_IS_OPTION_MENU (option_menu));
 
 	w = gtk_bin_get_child (GTK_BIN (option_menu->selected));
-	text = g_object_get_data (G_OBJECT (w), "option-menu-text");
-
-	if (!text && GTK_IS_LABEL (w))
+	if (GTK_IS_LABEL (w))
 		text = gtk_label_get_text (GTK_LABEL (w));
-
-	if (!text)
+	else
 		text = "";
 
-#if 0
-	g_print ("text = \"%s\"\n", text);
-#endif
-
 	gtk_label_set_text (option_menu->button_label, text);
 }
 
-static void
+void
 go_option_menu_select_item (GOOptionMenu *option_menu, GtkMenuItem *item)
 {
 	if (item == option_menu->selected)
@@ -122,7 +154,7 @@ go_option_menu_position (GtkMenu  *menu,
 	GOOptionMenu *option_menu = user_data;
 	GtkWidget *widget;
 	GtkRequisition requisition;
-	GList *children;
+	GList *children, *l;
 	gint screen_width;
 	gint menu_xpos;
 	gint menu_ypos;
@@ -141,11 +173,10 @@ go_option_menu_position (GtkMenu  *menu,
 	menu_ypos += allocation.y + allocation.height / 2 - 2;
 
 	children = gtk_container_get_children (GTK_CONTAINER (option_menu->menu));
-	while (children) {
-		GtkWidget *child = children->data;
+	for (l = children; l; l = l->next) {
+		GtkWidget *child = l->data;
 
-		if (GTK_IS_CHECK_MENU_ITEM (child) &&
-		    gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (child))) {
+		if (child == (GtkWidget*)option_menu->selected) {
 			gtk_widget_get_preferred_size (child, &requisition, NULL);
 			menu_ypos -= requisition.height / 2;
 			break;
@@ -158,6 +189,7 @@ go_option_menu_position (GtkMenu  *menu,
 
 		children = children->next;
 	}
+	g_list_free (children);
 
 	screen_width = gdk_screen_get_width (gtk_widget_get_screen (widget));
 
@@ -184,6 +216,9 @@ go_option_menu_button_press (GtkWidget      *widget,
 	option_menu = GO_OPTION_MENU (widget);
 
 	if (event->type == GDK_BUTTON_PRESS && event->button == 1) {
+		if (!gtk_widget_has_focus (widget) &&
+		    gtk_button_get_focus_on_click (GTK_BUTTON (widget)))
+			gtk_widget_grab_focus (widget);
 		gtk_menu_popup (GTK_MENU (option_menu->menu), NULL, NULL,
 				go_option_menu_position, option_menu,
 				event->button, event->time);
@@ -249,6 +284,19 @@ handle_menu_signals (GOOptionMenu *option_menu, gboolean connect)
 	}
 }
 
+/**
+ * go_option_menu_get_menu:
+ * @option_menu: #GOOptionMenu
+ *
+ * Returns: (transfer none): The currently set menu.
+ */
+GtkWidget *
+go_option_menu_get_menu (GOOptionMenu *option_menu)
+{
+	g_return_val_if_fail (GO_IS_OPTION_MENU (option_menu), NULL);
+	return (GtkWidget*)(option_menu->menu);
+}
+
 void
 go_option_menu_set_menu (GOOptionMenu *option_menu,
 			 GtkWidget *menu)
@@ -313,7 +361,9 @@ go_option_menu_set_history (GOOptionMenu *option_menu, GSList *selection)
 
 		while (1) {
 			int n = GPOINTER_TO_INT (selection->data);
-			GtkMenuItem *item = g_list_nth_data (gtk_container_get_children (GTK_CONTAINER (menu)), n);
+			GList *children = gtk_container_get_children (GTK_CONTAINER (menu));
+			GtkMenuItem *item = g_list_nth_data (children, n);
+			g_list_free (children);
 			selection = selection->next;
 			if (selection)
 				menu = GTK_MENU_SHELL (gtk_menu_item_get_submenu (item));
@@ -436,7 +486,10 @@ go_option_menu_init (GOOptionMenu *option_menu)
 	GtkBox *box;
 	GtkWidget *arrow, *sep;
 
+	gtk_widget_push_composite_child ();
+
 	gtk_widget_set_can_focus (GTK_WIDGET (option_menu), TRUE);
+	gtk_button_set_focus_on_click (GTK_BUTTON (option_menu), TRUE);
 	gtk_widget_set_can_default (GTK_WIDGET (option_menu), FALSE);
 	gtk_widget_set_receives_default (GTK_WIDGET (option_menu), FALSE);
 
@@ -457,31 +510,13 @@ go_option_menu_init (GOOptionMenu *option_menu)
 	gtk_box_pack_end (box, sep, FALSE, FALSE, 0);
 
 	gtk_container_add (GTK_CONTAINER (option_menu), GTK_WIDGET (box));
+
+	gtk_widget_pop_composite_child ();
 }
 
-GType
-go_option_menu_get_type (void)
-{
-	static GType option_menu_type = 0;
-
-	if (!option_menu_type) {
-		static const GTypeInfo option_menu_info =
-			{
-				sizeof (GOOptionMenuClass),
-				NULL,		/* base_init */
-				NULL,		/* base_finalize */
-				(GClassInitFunc) go_option_menu_class_init,
-				NULL,		/* class_finalize */
-				NULL,		/* class_data */
-				sizeof (GOOptionMenu),
-				0,		/* n_preallocs */
-				(GInstanceInitFunc) go_option_menu_init,
-			};
-
-		option_menu_type =
-			g_type_register_static (GTK_TYPE_BUTTON, "GOOptionMenu",
-						&option_menu_info, 0);
-	}
-
-	return option_menu_type;
-}
+GSF_CLASS (GOOptionMenu, go_option_menu,
+	   go_option_menu_class_init, go_option_menu_init,
+	   GTK_TYPE_BUTTON)
+#if 0
+;
+#endif
