@@ -128,6 +128,11 @@ general_linear_regressionl (long double *const *const xssT, int n,
 #define SUFFIX(_n) _n ## l
 #define FORMAT_f "Lf"
 #define FORMAT_g "Lg"
+#else
+/* It appears that gtk-doc is too dumb to handle this file.  Provide
+   a dummy type getter to make things work.  */
+GType go_regression_statl_get_type (void);
+GType go_regression_statl_get_type (void) { return G_TYPE_NONE; }
 #endif
 
 #endif
@@ -509,7 +514,7 @@ SUFFIX(regres_from_condition) (CONSTQMATRIX R, int n)
 	 * We need the absolute largest and smallest.
 	 */
 	for (i = 0; i < n; i++) {
-		DOUBLE e = SUFFIX(fabs)(SUFFIX(go_quad_value)(&R[i][i]));;
+		DOUBLE e = SUFFIX(fabs)(SUFFIX(go_quad_value)(&R[i][i]));
 		if (e < emin) emin = e;
 		if (e > emax) emax = e;
 	}
