@@ -267,6 +267,8 @@ outline_init (StylePrefState *state, gboolean enable, GOEditor *editor)
 		return;
 	}
 
+	go_editor_register_widget (editor, grid);
+
 	/* DashType */
 	w = go_selector_new_line_dash (style->line.dash_type,
 				       default_style->line.dash_type);
@@ -928,7 +930,7 @@ font_init (StylePrefState *state, guint32 enable, GOEditor *editor, GOCmdContext
 	gtk_grid_attach (GTK_GRID (grid), w, 1, 0, 1, 1);
 	gtk_widget_show (w);
 
-	w = go_font_sel_new ();
+	w = GTK_WIDGET (g_object_new (GO_TYPE_FONT_SEL, "show-style", TRUE, NULL));
 	go_font_sel_set_font (GO_FONT_SEL (w), style->font.font);
 	g_signal_connect (G_OBJECT (w), "font_changed",
 			  G_CALLBACK (cb_font_changed), state);
@@ -1323,7 +1325,7 @@ go_style_init (GOStyle *style)
 	style->text_layout.angle = 0.0;
 }
 
-static struct {
+static const struct {
 	GOStyleFill fstyle;
 	char const *name;
 } fill_names[] = {
@@ -1333,7 +1335,7 @@ static struct {
 	{ GO_STYLE_FILL_IMAGE,    "image" }
 };
 
-static struct {
+static const struct {
 	GOImageType fstyle;
 	char const *name;
 } image_tiling_names[] = {
